@@ -48,6 +48,7 @@ int verbose = FALSE;
 #define	FILENAME	"file"
 #define INTERFACE	"interface"
 #define INTERVAL	"interval"
+#define LOGTICK		"logtick"
 #define MAXLOAD1	"max-load-1"
 #define MAXLOAD5	"max-load-5"
 #define MAXLOAD15	"max-load-15"
@@ -55,6 +56,7 @@ int verbose = FALSE;
 #define MINMEM		"min-memory"
 #define SERVERPIDFILE	"pidfile"
 #define PING		"ping"
+#define PINGCOUNT	"ping-count"
 #define PRIORITY	"priority"
 #define REALTIME	"realtime"
 #define REPAIRBIN	"repair-binary"
@@ -62,10 +64,11 @@ int verbose = FALSE;
 #define TESTBIN		"test-binary"
 
 pid_t pid;
-int softboot = FALSE, watchdog = -1, load = -1, mem = -1, temp = -1, tint = 10, schedprio = 1;
+int softboot = FALSE, watchdog = -1, load = -1, mem = -1, temp = -1, tint = 10, logtick = 1, ticker = 0, schedprio = 1;
 char *tempname = NULL, *devname = NULL, *admin = "root", *progname;
 int maxload1 = 0, maxload5 = 0, maxload15 = 0, minpages = 0;
 int maxtemp = 120;
+int pingcount = 3;
 
 #if defined(_POSIX_MEMLOCK)
 int mlocked = FALSE, realtime = FALSE;
@@ -314,6 +317,11 @@ static void read_config(char *filename, char *progname)
 		    fprintf(stderr, "Ignoring invalid line in config file:\n%s\n", line);
 		else
 		    tint = atol(line + i);
+	    } else if (strncmp(line + i, LOGTICK, strlen(LOGTICK)) == 0) {
+		if (spool(line, &i, strlen(LOGTICK)))
+		    logtick = ticker = 1;
+		else
+		    logtick = ticker = atol(line + i);
 	    } else if (strncmp(line + i, DEVICE, strlen(DEVICE)) == 0) {
 		if (spool(line, &i, strlen(DEVICE)))
 			devname = NULL;
@@ -359,6 +367,11 @@ static void read_config(char *filename, char *progname)
 		else {
 			minpages = atol(line + i);
 		}
+	    } else if (strncmp(line + i, PINGCOUNT, strlen(PINGCOUNT)) == 0) {
+		if (spool(line, &i, strlen(PINGCOUNT)))
+		    fprintf(stderr, "Ignoring invalid line in config file:\n%s\n", line);
+		else
+		    pingcount = atol(line + i);
 	    } else {
 		fprintf(stderr, "Ignoring invalid line in config file:\n%s\n", line);
 	    }
@@ -726,7 +739,7 @@ int main(int argc, char *const argv[])
 	    
 	/* in ping mode ping the ip address */
 	for (act = target; act != NULL; act = act->next)
-	    do_check(check_net(act->name, act->parameter.net.sock_fp, act->parameter.net.to, act->parameter.net.packet, tint / 3), rbinary);
+	    do_check(check_net(act->name, act->parameter.net.sock_fp, act->parameter.net.to, act->parameter.net.packet, tint , pingcount), rbinary);
 
 	/* in user mode execute the given binary or just test fork() call */
 	do_check(check_bin(tbinary), rbinary);
@@ -734,12 +747,17 @@ int main(int argc, char *const argv[])
 	/* finally sleep some seconds */
 	sleep(tint);
 
+	if(logtick && (--ticker == 0)) {
+	  ticker = logtick;
+	  
 #if USE_SYSLOG
 	/* do verbose logging */
 	if (verbose) {
-	    count++;
+	    count += logtick;
+		ticker = 0;
 	    syslog(LOG_INFO, "still alive after %ld seconds = %ld interval(s)", count * tint, count);
 	}
 #endif				/* USE_SYSLOG */
+	}
     }
 }
